/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.jz.dmp.cmdexectool.scheduler.common.task.sql;

import com.alibaba.fastjson.JSONObject;
import com.jz.dmp.cmdexectool.common.constant.CommConstant;
import com.jz.dmp.cmdexectool.controller.bean.DmpProjectConfigInfoDto;
import com.jz.dmp.cmdexectool.entity.DmpSyncingDatasource;
import com.jz.dmp.cmdexectool.mapper.DmpSyncingDatasourceDao;
import com.jz.dmp.cmdexectool.scheduler.common.process.ResourceInfo;
import com.jz.dmp.cmdexectool.scheduler.common.task.AbstractParameters;
import com.jz.dmp.cmdexectool.scheduler.server.entity.TaskExecutionContext;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Sql/Hql parameter
 */
public class SqlParameters extends AbstractParameters {
	/**
	 * shell script
	 */
	private String script;

	private String taskAppId;
	
	/**
	* 数据源相关配置
	*/
	private Map<String, Object> source;

	/**
	* 目标相关配置
	*/
	private Map<String, Object> sink;
	
	/**
	* 环境相关配置
	*/
	private Map<String, Object> env;
	
	/**
	* ETL相关配置
	*/
	private Map<String, Object> transform;

	/**
	 * resource list
	 */
	private List<ResourceInfo> resourceList;

	public SqlParameters(String script, DmpProjectConfigInfoDto projectConfigInfoDto, DmpSyncingDatasourceDao dmpSyncingDatasourceDao) {
		this.script = script;
		
		JSONObject scriptObj = JSONObject.parseObject(script);
		String outputType = scriptObj.getString("outputType");
		
		String sqlScript = scriptObj.getString("sqlScript");
		
		
		//evn
		env.put("spark.app.name", "Waterdrop");
		//source
		Integer sourceId = scriptObj.getInteger("sourceId");
		DmpSyncingDatasource dmpSyncingDatasource = dmpSyncingDatasourceDao.queryById(sourceId);
		
		Map<String, Object> jdbcMap = new HashMap<String, Object>();
		jdbcMap.put("driver", "com.mysql.jdbc.Driver");
		jdbcMap.put("url", dmpSyncingDatasource.getJdbcUrl());
		//jdbcMap.put("table", value);
		//jdbcMap.put("result_table_name", value);
		//jdbcMap.put("user", dmpSyncingDatasource.getUserName());
		//jdbcMap.put("password", dmpSyncingDatasource.getPassword());
		//jdbcMap.put("", value);
		//jdbcMap.put("", value);
		//jdbcMap.put("", value);
		//jdbcMap.put("", value);
		source.put("jdbc", jdbcMap);
		
		if (CommConstant.OUTPUT_TYPE_CONSOLE.equals(outputType)) {
			//transform
			Map<String, Object> sqlMap = new HashMap<String, Object>();
			sqlMap.put("sql", sqlScript);
			transform.put("sql", sqlMap);
			//sink
			Map<String, Object> stdoutMap = new HashMap<String, Object>();
			stdoutMap.put("limit", 10);
			stdoutMap.put("serializer", "json");
			sink.put("stdout", stdoutMap);
		}else if (CommConstant.OUTPUT_TYPE_HDFS.equals(outputType)) {
			//transform
			
			//sink
			
		}else if (CommConstant.OUTPUT_TYPE_TABLE.equals(outputType)) {
			
		}else if (CommConstant.OUTPUT_TYPE_TOPIC.equals(outputType)) {
			
		}else if (CommConstant.OUTPUT_TYPE_API.equals(outputType)) {
			
		}
		
	}

	public String getScript() {
		return script;
	}

	public void setScript(String script) {
		this.script = script;
	}

	public String getTaskAppId() {
		return taskAppId;
	}

	public void setTaskAppId(String taskAppId) {
		this.taskAppId = taskAppId;
	}
	
	public Map<String, Object> getSource() {
		return source;
	}

	public void setSource(Map<String, Object> source) {
		this.source = source;
	}

	public Map<String, Object> getSink() {
		return sink;
	}

	public void setSink(Map<String, Object> sink) {
		this.sink = sink;
	}

	public Map<String, Object> getEnv() {
		return env;
	}

	public void setEnv(Map<String, Object> env) {
		this.env = env;
	}

	public Map<String, Object> getTransform() {
		return transform;
	}

	public void setTransform(Map<String, Object> transform) {
		this.transform = transform;
	}

	public List<ResourceInfo> getResourceList() {
		return resourceList;
	}

	public void setResourceList(List<ResourceInfo> resourceList) {
		this.resourceList = resourceList;
	}

	@Override
	public boolean checkParameters() {
		return script != null && !script.isEmpty();
	}

	@Override
	public List<ResourceInfo> getResourceFilesList() {
		return resourceList;
	}

	/**
	 * @Title: getTaskExecutionContext @Description:
	 * TODO(获取TaskExecutionContext) @param @param dmpDevelopTaskDto @param @return
	 * 参数 @return TaskExecutionContext 返回类型 @throws
	 */
	public TaskExecutionContext getTaskExecutionContext() {
		TaskExecutionContext taskExecutionContext = new TaskExecutionContext();

		// taskName;

		// taskType;
		taskExecutionContext.setTaskType(CommConstant.WORK_TYPE_SQL);
		// host;

		// executePath;
		// taskExecutionContext.setExecutePath("E:/test");
		// logPath;

		// taskJson;

		// globalParams;

		// projectId;

		// taskParams;
		taskExecutionContext.setTaskParams(JSONObject.toJSONString(this));

		// envFile;

		// taskAppId
		taskExecutionContext.setTaskAppId(taskAppId);

		return taskExecutionContext;
	}
}
